(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 8.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       157,          7]
NotebookDataLength[     13263,        368]
NotebookOptionsPosition[     12486,        338]
NotebookOutlinePosition[     12832,        353]
CellTagsIndexPosition[     12789,        350]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["M\[EAcute]todo do Ponto Fixo em Rn", "Subsection",
 CellChangeTimes->{{3.528102010438264*^9, 3.528102022640826*^9}}],

Cell["\<\
Implementa\[CCedilla]\[ATilde]o do m\[EAcute]todo do ponto fixo em Rn, para \
resolu\[CCedilla]\[ATilde]o de sistemas de equa\[CCedilla]\[OTilde]es n\
\[ATilde]o lineares da forma G (X) = X, em que X = (x_ 1, ... , x_n) e G = \
(g_ 1, ... , g_n). A converg\[EHat]ncia do m\[EAcute]todo \[EAcute] \
condicional e tipicamente de primeira ordem. 

Par\[AHat]metros de entrada:

*  G, X : a fun\[CCedilla]\[ATilde]o vectorial G e o seu argumento X
* X0     : vector que d\[AAcute] a aproxima\[CCedilla]\[ATilde]o inicial
* tol      : erro maximo desejado, medido com base da dist\[AHat]ncia entre \
as duas \[UAcute]ltimas iteradas.
* nmax : n\[UAcute]mero m\[AAcute]ximo de itera\[CCedilla]\[OTilde]es

Par\[AHat]metros de sa\[IAcute]da:

* vector num\[EAcute]rico com a solu\[CCedilla]\[ATilde]o do problema, \
correspondendo \[AGrave] \[UAcute]ltima itera\[CCedilla]\[ATilde]o calculada. \
Se o n\[UAcute]mero m\[AAcute]ximo de itera\[CCedilla]\[OTilde]es for \
atingido \[EAcute] emitida mensagem de erro.
\
\>", "Text",
 CellChangeTimes->{{3.5281020288055887`*^9, 3.5281021217860813`*^9}, {
  3.52810215403401*^9, 3.528102312691771*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"PontoFixo", "[", 
    RowBox[{"Gs_", ",", "X_", ",", "X0_", ",", "tol_", ",", "nmax_"}], "]"}], 
   ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "G", ",", "sol", ",", "oldsol", ",", "iter", ",", "n", ",", "i"}], 
      "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"(*", " ", 
      RowBox[{
      "Gs", " ", "e", " ", "X", " ", "devem", " ", "ser", " ", "vectores", 
       " ", "da", " ", "mesma", " ", "dimens\[ATilde]o"}], " ", "*)"}], " ", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"n", "=", 
       RowBox[{"Length", "[", "X", "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"G", "[", "s_", "]"}], ":=", 
       RowBox[{"Gs", "/.", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"X", "[", 
            RowBox[{"[", "i", "]"}], "]"}], "\[Rule]", 
           RowBox[{"s", "[", 
            RowBox[{"[", "i", "]"}], "]"}]}], ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", "1", ",", "n"}], "}"}]}], "]"}]}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"NormaInf", "[", "s_", "]"}], ":=", 
       RowBox[{"Max", "[", 
        RowBox[{"Abs", "[", "s", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"sol", "=", "X0"}], ";", "\[IndentingNewLine]", 
      RowBox[{"oldsol", "=", 
       RowBox[{"sol", "+", 
        RowBox[{"2", "*", "tol"}]}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"iter", "=", "0"}], ";", "\[IndentingNewLine]", 
      RowBox[{"While", "[", 
       RowBox[{
        RowBox[{"And", "[", 
         RowBox[{
          RowBox[{"iter", "\[LessEqual]", "nmax"}], ",", " ", 
          RowBox[{
           RowBox[{"NormaInf", "[", 
            RowBox[{"sol", "-", "oldsol"}], "]"}], ">", "tol"}]}], "]"}], ",",
         "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"oldsol", "=", "sol"}], ";", "\[IndentingNewLine]", 
         RowBox[{"sol", " ", "=", " ", 
          RowBox[{"G", "[", "sol", "]"}]}], ";", "\[IndentingNewLine]", 
         RowBox[{"iter", "++"}]}]}], "]"}], ";", "\[IndentingNewLine]", 
      RowBox[{"Print", "[", 
       RowBox[{
       "\"\<Foram realizadas \>\"", ",", "iter", ",", 
        "\"\< itera\[CCedilla]\[OTilde]es\>\""}], "]"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"iter", "\[GreaterEqual]", "nmax"}], ",", 
        RowBox[{
        "Print", "[", 
         "\"\<AVISO: N\[UAcute]mero m\[AAcute]ximo de itera\[CCedilla]\
\[OTilde]es foi atingido\>\"", "]"}]}], "]"}], ";", "\[IndentingNewLine]", 
      "sol"}]}], "\[IndentingNewLine]", "]"}]}], 
  "\[IndentingNewLine]"}]], "Input",
 CellChangeTimes->{{3.528102335099949*^9, 3.5281023600697927`*^9}, {
  3.528102464087284*^9, 3.528102670193475*^9}, {3.5281027392302637`*^9, 
  3.528102766812441*^9}, {3.528103103467539*^9, 3.528103103588254*^9}, {
  3.528103191142323*^9, 3.5281031913338957`*^9}, {3.5281032642889557`*^9, 
  3.528103297030409*^9}, {3.528103339353856*^9, 3.528103346352332*^9}, {
  3.5281034218648653`*^9, 3.528103485161414*^9}, {3.5292407844248934`*^9, 
  3.5292408132162933`*^9}}],

Cell[BoxData[
 RowBox[{"Exemplo", ":", " "}]], "Input",
 CellChangeTimes->{{3.528102779246876*^9, 3.5281027813005733`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"G", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Cos", "[", 
      RowBox[{"0.5", "*", "y"}], "]"}], ",", 
     RowBox[{"Sin", "[", 
      RowBox[{"0.3", "*", "x"}], "]"}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"X", "=", 
   RowBox[{"{", 
    RowBox[{"x", ",", "y"}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"X0", "=", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0"}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"nmax", "=", "1000"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"tol", "=", 
   RowBox[{"10", "^", 
    RowBox[{"(", 
     RowBox[{"-", "6"}], ")"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"PontoFixo", "[", 
  RowBox[{"G", ",", "X", ",", "X0", ",", "tol", ",", "nmax"}], 
  "]"}]}], "Input",
 CellChangeTimes->{{3.5281028670686197`*^9, 3.528102936222103*^9}, {
  3.528103045374734*^9, 3.5281030730875473`*^9}}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Foram realizadas \"\>", "\[InvisibleSpace]", "9", 
   "\[InvisibleSpace]", "\<\" itera\[CCedilla]\[OTilde]es\"\>"}],
  SequenceForm["Foram realizadas ", 9, " itera\[CCedilla]\[OTilde]es"],
  Editable->False]], "Print",
 CellChangeTimes->{3.5281034874939623`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0.9893274388315207`", ",", "0.2924599023466555`"}], 
  "}"}]], "Output",
 CellChangeTimes->{
  3.528103074350605*^9, 3.528103110684782*^9, 3.528103194863462*^9, {
   3.52810327256966*^9, 3.528103300620596*^9}, 3.528103349208734*^9, {
   3.528103434438221*^9, 3.528103453534562*^9}, 3.528103487507534*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{
   RowBox[{
    RowBox[{"eta", "=", "1.6"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"n", "=", "2"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"a", "=", 
     RowBox[{"Table", "[", 
      RowBox[{"0.5", ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "1", ",", "n"}], "}"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"G", "[", "q_", "]"}], ":=", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"Sum", "[", 
            RowBox[{
             RowBox[{"q", "[", 
              RowBox[{"[", "j", "]"}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"j", ",", "1", ",", "n"}], "}"}]}], "]"}], ")"}], "^", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "/", "eta"}], ")"}]}], ")"}], "/", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{"1", "/", "eta"}], ")"}], "*", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"Sum", "[", 
              RowBox[{
               RowBox[{"q", "[", 
                RowBox[{"[", "j", "]"}], "]"}], ",", 
               RowBox[{"{", 
                RowBox[{"j", ",", "1", ",", "n"}], "}"}]}], "]"}], "^", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", 
                RowBox[{"(", 
                 RowBox[{"1", "/", "eta"}], ")"}]}], "-", "1"}], ")"}]}], 
            ")"}]}], "+", 
          RowBox[{"a", "[", 
           RowBox[{"[", "i", "]"}], "]"}]}], ")"}]}], "\[IndentingNewLine]", 
       ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "1", ",", "n"}], "}"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"X0", "=", 
     RowBox[{"{", 
      RowBox[{"0.5", ",", "0.5"}], "}"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"PontoFixo", "[", 
     RowBox[{"tol_", ",", "nmax_"}], "]"}], ":=", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"sol", ",", "oldsol", ",", "iter", ",", "n", ",", "i"}], "}"}],
       ",", "\[IndentingNewLine]", 
      RowBox[{"(*", " ", 
       RowBox[{
       "Gs", " ", "e", " ", "X", " ", "devem", " ", "ser", " ", "vectores", 
        " ", "da", " ", "mesma", " ", "dimens\[ATilde]o"}], " ", "*)"}], " ", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"n", "=", 
        RowBox[{"Length", "[", "X0", "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"NormaInf", "[", "s_", "]"}], ":=", 
        RowBox[{"Max", "[", 
         RowBox[{"Abs", "[", "s", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
       
       RowBox[{"sol", "=", "X0"}], ";", "\[IndentingNewLine]", 
       RowBox[{"oldsol", "=", 
        RowBox[{"sol", "+", 
         RowBox[{"2", "*", "tol"}]}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"iter", "=", "0"}], ";", "\[IndentingNewLine]", 
       RowBox[{"While", "[", 
        RowBox[{
         RowBox[{"And", "[", 
          RowBox[{
           RowBox[{"iter", "\[LessEqual]", "nmax"}], ",", " ", 
           RowBox[{
            RowBox[{"NormaInf", "[", 
             RowBox[{"sol", "-", "oldsol"}], "]"}], ">", "tol"}]}], "]"}], 
         ",", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"oldsol", "=", "sol"}], ";", "\[IndentingNewLine]", 
          RowBox[{"sol", " ", "=", " ", 
           RowBox[{"G", "[", "sol", "]"}]}], ";", "\[IndentingNewLine]", 
          RowBox[{"iter", "++"}]}]}], "]"}], ";", "\[IndentingNewLine]", 
       RowBox[{"Print", "[", 
        RowBox[{
        "\"\<Foram realizadas \>\"", ",", "iter", ",", 
         "\"\< itera\[CCedilla]\[OTilde]es\>\""}], "]"}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"iter", "\[GreaterEqual]", "nmax"}], ",", 
         RowBox[{
         "Print", "[", 
          "\"\<AVISO: N\[UAcute]mero m\[AAcute]ximo de itera\[CCedilla]\
\[OTilde]es foi atingido\>\"", "]"}]}], "]"}], ";", "\[IndentingNewLine]", 
       "sol"}]}], "\[IndentingNewLine]", "]"}]}]}]}]], "Input",
 CellChangeTimes->{{3.5292408589812937`*^9, 3.5292410463518934`*^9}, {
  3.529241158157093*^9, 3.5292411702728934`*^9}, {3.529241203552493*^9, 
  3.5292412496946936`*^9}, {3.529241309081293*^9, 3.5292414738236933`*^9}, {
  3.5292415533096933`*^9, 3.5292415588064933`*^9}, {3.5292417498708935`*^9, 
  3.5292417786532936`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"PontoFixo", "[", 
  RowBox[{
   RowBox[{"10", "^", 
    RowBox[{"(", 
     RowBox[{"-", "12"}], ")"}]}], ",", "5000"}], "]"}]], "Input",
 CellChangeTimes->{{3.5292410955332937`*^9, 3.529241101459893*^9}, {
  3.5292411436498933`*^9, 3.5292411517700934`*^9}}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Foram realizadas \"\>", "\[InvisibleSpace]", "14", 
   "\[InvisibleSpace]", "\<\" itera\[CCedilla]\[OTilde]es\"\>"}],
  SequenceForm["Foram realizadas ", 14, " itera\[CCedilla]\[OTilde]es"],
  Editable->False]], "Print",
 CellChangeTimes->{{3.5292411525060935`*^9, 3.5292411724982934`*^9}, 
   3.5292412192054935`*^9, 3.5292412532366934`*^9, 3.529241509270893*^9, 
   3.5292416293514934`*^9, 3.5292417831250935`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0.9318126138577986`", ",", "0.9318126138577986`"}], 
  "}"}]], "Output",
 CellChangeTimes->{{3.5292411525210934`*^9, 3.5292411724982934`*^9}, 
   3.5292412192074933`*^9, 3.529241253238693*^9, 3.529241509282893*^9, 
   3.5292416293604937`*^9, 3.5292417831350937`*^9}]
}, Open  ]],

Cell[BoxData[" "], "Input",
 CellChangeTimes->{3.5292416788480935`*^9}]
}, Open  ]]
},
WindowSize->{758, 605},
WindowMargins->{{169, Automatic}, {Automatic, -1}},
FrontEndVersion->"8.0 for Microsoft Windows (64-bit) (February 23, 2011)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[579, 22, 122, 1, 36, "Subsection"],
Cell[704, 25, 1148, 24, 281, "Text"],
Cell[1855, 51, 3184, 76, 352, "Input"],
Cell[5042, 129, 123, 2, 31, "Input"],
Cell[CellGroupData[{
Cell[5190, 135, 939, 29, 132, "Input"],
Cell[6132, 166, 311, 6, 23, "Print"],
Cell[6446, 174, 344, 7, 30, "Output"]
}, Open  ]],
Cell[6805, 184, 4496, 118, 472, "Input"],
Cell[CellGroupData[{
Cell[11326, 306, 281, 7, 31, "Input"],
Cell[11610, 315, 465, 8, 23, "Print"],
Cell[12078, 325, 306, 6, 30, "Output"]
}, Open  ]],
Cell[12399, 334, 71, 1, 31, "Input"]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
